import { Context } from 'react';
import type { Locale, Translations } from './types';
export interface I18nContextValue {
    /**
     * Array of `Locale`s that are supported by the current app or context. Defaults to all the locales that exist in `components`.
     */
    supportedLocales: Locale[];
    /**
     * App-specific translations indexed by locale (e.g. `{ en: { key: 'Value in English' }, fr: { key: 'Value in French' } }`).
     * Merged into the default translations from `components`.
     */
    translations: Translations;
    /**
     * The current locale, which was either set explicitly or determined from the URL, falling back to the user's preferred locale,
     * or in last resort, to the default locale (English).
     */
    locale: Locale;
    /**
     * Function that should change the value of `locale`.
     */
    setLocale: (locale: Locale) => void;
    /**
     * The part of the URL that follows the host + the current locale, including a leading slash.
     */
    pathWithoutLocale: string;
}
export interface I18nContext extends Context<I18nContextValue> {
    defaultValue: I18nContextValue;
}
export declare const I18nContext: I18nContext;
